@@ -50,6 +50,10 @@ class mySql:
 		self.dbUsername = _dbUsername
 		self._db_connect()
 
+
+	def __del__(self):
+		self.db.close()
+	
 	
 	def execInsertQuery(self, sql, data):
 		"""
