@@ -100,6 +100,16 @@ def delhubgroup(groupName):
 	_del_jos_xgroups(db, groupName)
 
 
-def addhubgroup(db, groupName, groupDescription):
+def addhubgroup(groupName, groupDescription):
+
+	# grab config options
+	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
+	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
+	dbName = hubzero.config.webconfig.getWebConfigDBName()
+	db =  hubzero.data.db.mySql("localhost", dbName, dbUserName, dbPW)
+
 	gidNumber = _insert_jos_xgroups(db, groupName, groupDescription)
+
+	_add_ldap_group(groupName, groupDescription, gidNumber)
+
 	return gidNumber	
\ No newline at end of file
